@@ -1,5 +1,5 @@
 from .users import Users, Owners, Credentials
-from .apiaries import Apiaries, ApiaryStatuses, HoneyTypes
+from .apiaries import Apiaries, HoneyTypes
 from .hives import Hives, HiveConditions
 from .swarms import Swarms, SwarmHealthStatuses
 from .events import Events, EventStatuses, EventTypes
